c     ******************************************************************
c     Jacquemoud S., Ustin S.L., Verdebout J., Schmuck G., Andreoli G.,
c     Hosgood B. (1995), PROSPECT return, Remote Sens, Environ., in
c     preparation.
c     Jacquemoud S., Baret F. (1990), PROSPECT: a model of leaf optical
c     properties spectra, Remote Sens. Environ., 34:75-91.
c     ******************************************************************
c
c     Stephane JACQUEMOUD 
c
c     University of California, Davis
c     Department of Land, Air, and Water Resources
c     Davis, CA 95616
c     USA
c     tel: (1)-916-752-5092
c     fax: (1)-916-752-5262
c     E-mail: stephane@vache.ucdavis.edu
c     Mosaic: http://vaca.ucdavis.edu/staff/stephane/index.html
c
c     version 2.01 (10 April 1995)
c
c     ******************************************************************
c
c Usage:
c
c     dkl  = sum_j(c(j)*acoef(j))/vai
c     call prospect(rnnl, dkl, vai, refl, tran)
c
c     cab  - chlorophyll, g/cm^2
c     cw   - water, cm
c     cdm  - dry matter, mg/cm^2
c     cbr  - brown pigments, relative units
c     rnnl - refractive index
c     vai  - the number of cell layers
c
c
c     ******************************************************************

      subroutine prospect(rnnl, dkl, vai, refl, tran)

c
      implicit double precision (a-h, o-z)
      include 'nch.h'
c     common /pidr/ pi, dr
c

c     ******************************************************************
c     reflectance and transmittance of one layer
c     ******************************************************************
c     Allen W.A., Gausman H.W., Richardson A.J., Thomas J.R. (1969),
c     Interaction of isotropic ligth with a compact plant leaf, J. Opt.
c     Soc. Am., 59(10):1376-1379.
c     Jacquemoud S., Baret F. (1990), Prospect: a model of leaf optical
c     properties spectra, Remote Sens. Environ., 34:75-91.
c     ******************************************************************

      if (dkl .le. 0.d0) then
        dkl = 1.d0
      else
        call s13aaf(dkl, rinex)
        dkl = (1.d0 - dkl)*exp(-dkl) + dkl**2*rinex
      endif

      teta  = 90.d0*dr
      refra = rnnl
c
      call tav(teta, refra, tau)
c
      t1    = tau
      teta  = 60.d0*dr
c
      call tav(teta, refra, tau)
c
      t2    = tau
      x1    = 1.d0 - t1
      x2    = t1**2*dkl**2*(rnnl**2 - t1)
      x3    = t1**2*dkl*rnnl**2
      x4    = rnnl**4 - dkl**2*(rnnl**2 - t1)**2
      x5    = t2/t1
      x6    = x5*(t1 - 1.d0) + 1.d0 - t2
      rlf   = x1 + x2/x4
      tlf   = x3/x4
      ra    = x5*rlf + x6
      ta    = x5*tlf

c     ******************************************************************
c     reflectance and transmittance of N layers
c     ******************************************************************
c     Stokes G.G. (1862), On the intensity of the light reflected from
c     or transmitted through a pile of plates, Proc. Roy. Soc. Lond.,
c     11:545 - 556.
c     ******************************************************************

      deltp = (tlf**2 - rlf**2 - 1.d0)**2 - 4.d0*rlf**2
      alfp  = (1.d0 + rlf**2 - tlf**2 + dsqrt(deltp))/(2.d0*rlf)
      betp  = (1.d0 + rlf**2 - tlf**2 - dsqrt(deltp))/(2.d0*rlf)
      va    = (1.d0 + rlf**2 - tlf**2 + dsqrt(deltp))/(2.d0*rlf)
      vb    = dsqrt(betp*(alfp - rlf)/(alfp*(betp - rlf)))
      sp1   = ra*(va*vb**(vai - 1.d0) - va**(-1)*vb**(-(vai - 1.d0)))
     &      + (ta*tlf - ra*rlf)*(vb**(vai - 1.d0) - vb**(-(vai - 1.d0)))
      sp2   = ta*(va - va**(-1.d0))
      sp3   = va*vb**(vai - 1.d0) - va**(-1)*vb**(-(vai - 1.d0))
     &      - rlf*(vb**(vai - 1.d0) - vb**(-(vai - 1.d0)))
      refl  = sp1/sp3
      tran  = sp2/sp3

      return
      end



c      ******************************************************************
c      exponential integral: int(exp(-t)/t, t = xs..inf)
c      ******************************************************************

      subroutine s13aaf(dkl, rinex)
c
c
      implicit double precision (a-h, o-z)
c
      if (dkl .gt. 4.d0) goto 10

      xs = 0.5d0 * dkl - 1.d0
      ys = ((((((((((((((( - 3.60311230482612224d - 13
     &  *xs + 3.46348526554087424d-12)*xs - 2.99627399604128973d-11)
     &  *xs + 2.57747807106988589d-10)*xs - 2.09330568435488303d-9)
     &  *xs + 1.59501329936987818d-8)*xs  - 1.13717900285428895d-7)
     &  *xs + 7.55292885309152956d-7)*xs  - 4.64980751480619431d-6)
     &  *xs + 2.63830365675408129d-5)*xs  - 1.37089870978830576d-4)
     &  *xs + 6.47686503728103400d-4)*xs  - 2.76060141343627983d-3)
     &  *xs + 1.05306034687449505d-2)*xs  - 3.57191348753631956d-2)
     &  *xs + 1.07774527938978692d-1)*xs  - 2.96997075145080963d-1
      ys = (ys*xs + 8.64664716763387311d-1)*xs + 7.42047691268006429d-1
      rinex = ys - log(dkl)
      goto 30

10    continue
      if (dkl .ge. 85.d0) go to 20
      xs = 14.5d0 / (dkl + 3.25d0) - 1.d0
      ys = ((((((((((((((( - 1.62806570868460749d-12
     &  *xs - 8.95400579318284288d-13)*xs - 4.08352702838151578d-12)
     &  *xs - 1.45132988248537498d-11)*xs - 8.35086918940757852d-11)
     &  *xs - 2.13638678953766289d-10)*xs - 1.10302431467069770d-9)
     &  *xs - 3.67128915633455484d-9)*xs  - 1.66980544304104726d-8)
     &  *xs - 6.11774386401295125d-8)*xs  - 2.70306163610271497d-7)
     &  *xs - 1.05565006992891261d-6)*xs  - 4.72090467203711484d-6)
     &  *xs - 1.95076375089955937d-5)*xs  - 9.16450482931221453d-5)
     &  *xs - 4.05892130452128677d-4)*xs  - 2.14213055000334718d-3
      ys    = ((ys*xs - 1.06374875116569657d-2)*xs - 
     &        8.50699154984571871d-2)*xs + 9.23755307807784058d-1
      rinex = exp(-dkl) * ys / dkl
      goto 30

20    continue
      rinex = 0.d0

30    continue
c
      return
      end

c     ******************************************************************
c     evaluation of tav for any solid angle
c     ******************************************************************
c     Stern F. (1964), Transmission of isotropic radiation across an
c     interface between two dielectrics, Appl. Opt., 3(1):111-113.
c     Allen W.A. (1973), Transmission of isotropic light across a
c     dielectric surface in two and three dimensions, J. Opt. Soc. Am.,
c     63(6):664 - 666.
c     ******************************************************************


      subroutine tav(teta, refra, tau)
c
c
      implicit double precision (a-h, o-z)
      include 'nch.h'
c
      data eps/.1d-6/
c
      pi12   = pi/2.d0
      r2     = refra**2
      rp     = r2 + 1.d0
      rm     = r2 - 1.d0
      atav   = (refra + 1.d0)**2/2.d0
      rktav  = -(r2 - 1.d0)**2/4.d0
      ds     = sin(teta)

      if (abs(teta) .le. eps) then
         tau = 4.d0*refra/(refra + 1.d0)**2
      else 
         if (abs(teta - pi12) .le. eps) then
            b1  = 0.d0
         else
            xxx = (ds**2 - rp/2.d0)**2 + rktav
            b1  = dsqrt(xxx)
         endif

         b2   = ds**2 - rp/2.d0
         btav = b1 - b2
         ts   = (rktav**2/(6.d0*btav**3) + rktav/btav - btav/2.d0) - 
     &          (rktav**2/(6.d0*atav**3) + rktav/atav - atav/2.d0)
         tp1  = -2.d0*r2*(btav - atav)/rp**2
         tp2  = -2.d0*r2*rp*log(btav/atav)/rm**2
         tp3  = r2*(1.d0/btav - 1.d0/atav)/2.d0
         tp4  = 16.d0*r2**2*(r2**2 + 1.d0)*log((2.d0*rp*btav - rm**2)/
     &          (2.d0*rp*atav - rm**2))/(rp**3*rm**2)
         tp5  = 16.d0*r2**3*(1.d0/(2.d0*rp*btav - rm**2) - 1.d0/
     &          (2.d0*rp*atav - rm**2))/rp**3
         tp   = tp1 + tp2 + tp3 + tp4 + tp5
         tau  = (ts + tp)/(2.d0*ds**2)
      endif
c
      return
      end
*
******************************************************************
*
